@@ -65,9 +65,9 @@ var group__libopenmpt__c =
     [ "openmpt_error_func", "group__libopenmpt__c.html#gaa68155b220861de6218bc6b599071f21", null ],
     [ "openmpt_log_func", "group__libopenmpt__c.html#gaeec3c004981950af696bfd2688e250b2", null ],
     [ "openmpt_module", "group__libopenmpt__c.html#gadb90c01fba5864c0359a28c2d4151dd7", null ],
-    [ "openmpt_module_initial_ctl", "group__libopenmpt__c.html#gab80d8d1ce0d36ff2d7e7fca314dc9af8", null ],
-    [ "openmpt_stream_buffer", "group__libopenmpt__c.html#gac2b9c542d2641b95e1f936cdb32c8999", null ],
-    [ "openmpt_stream_callbacks", "group__libopenmpt__c.html#ga0d95b2f481612b600a09ee2ebee4d522", null ],
+    [ "openmpt_module_initial_ctl", "group__libopenmpt__c.html#gac5daa1e631884cf990a326442a55f98a", null ],
+    [ "openmpt_stream_buffer", "group__libopenmpt__c.html#ga7299bdb1270ac987339a5bab822a3973", null ],
+    [ "openmpt_stream_callbacks", "group__libopenmpt__c.html#gab7032a4db4a21f5b0ef8bd0ba53442e1", null ],
     [ "openmpt_stream_read_func", "group__libopenmpt__c.html#gaeccd341852695cc71d8a5e3ac47ff168", null ],
     [ "openmpt_stream_seek_func", "group__libopenmpt__c.html#ga88bc398e2fedc565ef8747bf49abdae5", null ],
     [ "openmpt_stream_tell_func", "group__libopenmpt__c.html#gaf5b929ef6551750bb10acf4a2fadc341", null ],
@@ -95,7 +95,15 @@ var group__libopenmpt__c =
     [ "openmpt_module_create_from_memory", "group__libopenmpt__c.html#ga53377a365f001a99ae4626918e55b25e", null ],
     [ "openmpt_module_create_from_memory2", "group__libopenmpt__c.html#ga8237a4d9dfb0f33c7cd0a2926f30a25f", null ],
     [ "openmpt_module_ctl_get", "group__libopenmpt__c.html#ga20d871022840893e6f4cb13ad78a0ff7", null ],
+    [ "openmpt_module_ctl_get_boolean", "group__libopenmpt__c.html#ga79c1fc512437220d9f65556723326c78", null ],
+    [ "openmpt_module_ctl_get_floatingpoint", "group__libopenmpt__c.html#gac6e1f6ec3d9cc82fa3df5e63dc5b5350", null ],
+    [ "openmpt_module_ctl_get_integer", "group__libopenmpt__c.html#gab4cd78a172569a5d02c4e41c3caac18c", null ],
+    [ "openmpt_module_ctl_get_text", "group__libopenmpt__c.html#ga13b040e57fd61854766b3d3fdca14b3a", null ],
     [ "openmpt_module_ctl_set", "group__libopenmpt__c.html#ga384de8fb7266821e7a3677460861593e", null ],
+    [ "openmpt_module_ctl_set_boolean", "group__libopenmpt__c.html#gab178566ca8e2280f4389370200b00ad5", null ],
+    [ "openmpt_module_ctl_set_floatingpoint", "group__libopenmpt__c.html#ga7af8284475e3411b25d3f8c9686b02e6", null ],
+    [ "openmpt_module_ctl_set_integer", "group__libopenmpt__c.html#ga6a3990be4d7140e255fbc96e1eaed3db", null ],
+    [ "openmpt_module_ctl_set_text", "group__libopenmpt__c.html#ga8a4b646f940bd9e9527dbda4edbeca17", null ],
     [ "openmpt_module_destroy", "group__libopenmpt__c.html#ga40d27bb0ef054c3cd5e7ae3e85ed64e1", null ],
     [ "openmpt_module_error_clear", "group__libopenmpt__c.html#gaceaa2675b539674c1611d1e8a392aa87", null ],
     [ "openmpt_module_error_get_last", "group__libopenmpt__c.html#ga7ffc363899565eebe05d38a670050c83", null ],
@@ -110,6 +118,7 @@ var group__libopenmpt__c =
     [ "openmpt_module_get_current_channel_vu_rear_left", "group__libopenmpt__c.html#ga3c5d64718d0d574bf94bd9f13aa3b8a1", null ],
     [ "openmpt_module_get_current_channel_vu_rear_right", "group__libopenmpt__c.html#ga459facd9def73d056190a76882da29b6", null ],
     [ "openmpt_module_get_current_channel_vu_right", "group__libopenmpt__c.html#gab90660d5d9fa932cfff118023c4b56c8", null ],
+    [ "openmpt_module_get_current_estimated_bpm", "group__libopenmpt__c.html#gae3ed09be74bd9e5dc78d424608a17e72", null ],
     [ "openmpt_module_get_current_order", "group__libopenmpt__c.html#ga88bd245db9a3e857443920bf68f093a6", null ],
     [ "openmpt_module_get_current_pattern", "group__libopenmpt__c.html#ga9f2013da0ddda5888d8ac9821193c269", null ],
     [ "openmpt_module_get_current_playing_channels", "group__libopenmpt__c.html#ga145570605cff14c147d096e93bd16dbc", null ],
