@@ -1,3 +1,27 @@
+/*
+ @licstart  The following is the entire license notice for the JavaScript code in this file.
+
+ The MIT License (MIT)
+
+ Copyright (C) 1997-2020 by Dimitri van Heesch
+
+ Permission is hereby granted, free of charge, to any person obtaining a copy of this software
+ and associated documentation files (the "Software"), to deal in the Software without restriction,
+ including without limitation the rights to use, copy, modify, merge, publish, distribute,
+ sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
+ furnished to do so, subject to the following conditions:
+
+ The above copyright notice and this permission notice shall be included in all copies or
+ substantial portions of the Software.
+
+ THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
+ BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
+ NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
+ DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+
+ @licend  The above is the entire license notice for the JavaScript code in this file
+*/
 var NAVTREE =
 [
   [ "libopenmpt", "index.html", [
@@ -8,16 +32,16 @@ var NAVTREE =
       [ "Website", "index.html#toc_website", null ],
       [ "License", "index.html#toc_license", null ]
     ] ],
-    [ "Quick Start", "quickstart.html", null ],
     [ "README", "md_README.html", null ],
     [ "Dependencies", "dependencies.html", null ],
+    [ "Getting Started", "gettingstarted.html", null ],
     [ "Packaging", "packaging.html", null ],
     [ "Contributing", "md_doc_contributing.html", null ],
-    [ "Coding conventions", "md_doc_libopenmpt_styleguide.html", null ],
+    [ "libopenmpt Style Guide", "md_doc_libopenmpt_styleguide.html", null ],
+    [ "OpenMPT Style Guide", "md_doc_openmpt_styleguide.html", null ],
     [ "Tests", "tests.html", null ],
     [ "Changelog", "changelog.html", null ],
-    [ "TODO", "todo.html", null ],
-    [ "How to add support for new module formats", "md_doc_module_formats.html", null ],
+    [ "Adding support for new module formats", "md_doc_module_formats.html", null ],
     [ "C++ API", "libopenmpt_cpp_overview.html", [
       [ "Error Handling", "libopenmpt_cpp_overview.html#libopenmpt_cpp_error", null ],
       [ "Strings", "libopenmpt_cpp_overview.html#libopenmpt_cpp_strings", null ],
@@ -51,8 +75,8 @@ var NAVTREE =
     ] ],
     [ "Deprecated List", "deprecated.html", null ],
     [ "Modules", "modules.html", "modules" ],
-    [ "Namespaces", null, [
-      [ "Namespace List", "namespaces.html", "namespaces" ],
+    [ "Namespaces", "namespaces.html", [
+      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
       [ "Namespace Members", "namespacemembers.html", [
         [ "All", "namespacemembers.html", null ],
         [ "Functions", "namespacemembers_func.html", null ],
@@ -74,8 +98,8 @@ var NAVTREE =
         [ "Related Functions", "functions_rela.html", null ]
       ] ]
     ] ],
-    [ "Files", null, [
-      [ "File List", "files.html", "files" ],
+    [ "Files", "files.html", [
+      [ "File List", "files.html", "files_dup" ],
       [ "File Members", "globals.html", [
         [ "All", "globals.html", "globals_dup" ],
         [ "Functions", "globals_func.html", null ],
@@ -90,8 +114,9 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "annotated.html",
-"group__libopenmpt__c.html#ga3d83925bb2083e25515a79a48321a4ce",
-"group__libopenmpt__c.html#gaff878452d42b028d3c764794524f07cc"
+"group__libopenmpt__c.html#ga35b34623ad43234f71b2fc6f1bdc67ac",
+"group__libopenmpt__c.html#gaeec3c004981950af696bfd2688e250b2",
+"structopenmpt__module__ext__interface__interactive.html#a59a42f9d5774438d4052de5aa066ee9f"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
